@@ -14,8 +14,9 @@ import struct
 import protocol
 import datatype
 import decimal
+import sys
 
-from exception import DataError, EndOfStream, ProgrammingError, db_error_handler
+from exception import DataError, EndOfStream, ProgrammingError, db_error_handler, BatchError
 from datatype import TypeObjectFromNuodb
 
 from statement import Statement, PreparedStatement, ExecutionResult
@@ -94,7 +95,7 @@ class EncodedSession(Session):
         @type parameters dict[str,str]
         @type cp crypt.ClientPassword
         """
-        self._putMessageId(protocol.OPENDATABASE).putInt(protocol.EXECUTEPREPAREDUPDATE).putString(db_name).putInt(len(parameters))
+        self._putMessageId(protocol.OPENDATABASE).putInt(protocol.CURRENT_PROTOCOL_VERSION).putString(db_name).putInt(len(parameters))
         for (k, v) in parameters.iteritems():
             self.putString(k).putString(v)
         self.putNull().putString(cp.genClientKey())
@@ -111,8 +112,8 @@ class EncodedSession(Session):
         try:
             self._putMessageId(protocol.AUTHENTICATION).putString(protocol.AUTH_TEST_STR)
             self._exchangeMessages()
-        except SessionException:
-            raise ProgrammingError('Invalid database username or password')
+        except SessionException as e:
+            raise ProgrammingError('Failed to authenticate: ' + str(e)), None, sys.exc_info()[2]
 
 
     def get_autocommit(self):
@@ -239,12 +240,25 @@ class EncodedSession(Session):
         self.putInt(len(param_lists))
         self._exchangeMessages()
 
+        results = []
+        error_code = None
+        error_string = None
+
         for _ in param_lists:
             result = self.getInt()
+            results.append(result)
             if result == -3:
-                error_code = self.getInt()
-                error_string = self.getString()
-                db_error_handler(error_code, error_string)
+                ec = self.getInt()
+                es = self.getString()
+                # only report first
+                if error_code is None:
+                    error_code = ec
+                    error_string = es
+
+        if error_code is not None:
+            raise BatchError(protocol.stringifyError[error_code] + ': ' + error_string, results)
+
+        return results
 
     def fetch_result_set(self, statement):
         """
@@ -333,6 +347,8 @@ class EncodedSession(Session):
             scale = self.getInt()
             self.getInt()       # flags
 
+            """TODO: type information should be derived from the type (column_type) not the
+                     typename.  """
             description[i] = [column_name, TypeObjectFromNuodb(column_type_name),
                               column_display_size, None, precision, scale, None]
 
@@ -346,8 +362,6 @@ class EncodedSession(Session):
         Start a message with the messageId.
         @type messageId int
         """
-        if self.__output is not None:
-            raise SessionException('no')
         self.__output = ''
         self.putInt(messageId, isMessageId=True)
         return self
